Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(829)

Unified Diff: chrome/browser/ui/browser.h

Issue 12386019: Instant: Use only one hidden WebContents per profile. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/browser.h
diff --git a/chrome/browser/ui/browser.h b/chrome/browser/ui/browser.h
index 7fd04a9364e82c48d1972254c34d4b3875605f41..911b25ef8168d583f12ecd25c52a7959359b689d 100644
--- a/chrome/browser/ui/browser.h
+++ b/chrome/browser/ui/browser.h
@@ -456,11 +456,10 @@ class Browser : public TabStripModelObserver,
// Show the first run search engine bubble on the location bar.
void ShowFirstRunBubble();
// If necessary, update the bookmark bar state according to the instant
// preview state: when instant preview shows suggestions and bookmark bar is
// still showing attached, hide it.
- void MaybeUpdateBookmarkBarStateForInstantPreview(
- const chrome::search::Mode& mode);
+ void MaybeUpdateBookmarkBarStateForInstantOverlay();
FullscreenController* fullscreen_controller() const {
return fullscreen_controller_.get();
@@ -456,11 +456,10 @@ class Browser : public TabStripModelObserver,
// Show the first run search engine bubble on the location bar.
void ShowFirstRunBubble();
- // If necessary, update the bookmark bar state according to the instant
- // preview state: when instant preview shows suggestions and bookmark bar is
+ // If necessary, update the bookmark bar state according to the Instant
+ // overlay state: when Instant overlay shows suggestions and bookmark bar is
// still showing attached, hide it.

Powered by Google App Engine
This is Rietveld 408576698